@@ -588,6 +588,44 @@ class EsPublicAcl(AbstractModel):
         self.WhiteIpList = params.get("WhiteIpList")
 
 
+class GetRequestTargetNodeTypesRequest(AbstractModel):
+    """GetRequestTargetNodeTypes请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: 实例ID
+        :type InstanceId: str
+        """
+        self.InstanceId = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+
+
+class GetRequestTargetNodeTypesResponse(AbstractModel):
+    """GetRequestTargetNodeTypes返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TargetNodeTypes: 接收请求的目标节点类型列表
+        :type TargetNodeTypes: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TargetNodeTypes = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TargetNodeTypes = params.get("TargetNodeTypes")
+        self.RequestId = params.get("RequestId")
+
+
 class InstanceInfo(AbstractModel):
     """实例详细信息
 
@@ -718,6 +756,9 @@ class InstanceInfo(AbstractModel):
         :param SceneType: 场景化模板类型：0、不开启；1、通用场景；2、日志场景；3、搜索场景
 注意：此字段可能返回 null，表示取不到有效值。
         :type SceneType: int
+        :param KibanaConfig: Kibana配置项
+注意：此字段可能返回 null，表示取不到有效值。
+        :type KibanaConfig: str
         """
         self.InstanceId = None
         self.InstanceName = None
@@ -772,6 +813,7 @@ class InstanceInfo(AbstractModel):
         self.KibanaPrivateAccess = None
         self.SecurityType = None
         self.SceneType = None
+        self.KibanaConfig = None
 
 
     def _deserialize(self, params):
@@ -853,6 +895,7 @@ class InstanceInfo(AbstractModel):
         self.KibanaPrivateAccess = params.get("KibanaPrivateAccess")
         self.SecurityType = params.get("SecurityType")
         self.SceneType = params.get("SceneType")
+        self.KibanaConfig = params.get("KibanaConfig")
 
 
 class InstanceLog(AbstractModel):
@@ -1509,6 +1552,44 @@ class UpdatePluginsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class UpdateRequestTargetNodeTypesRequest(AbstractModel):
+    """UpdateRequestTargetNodeTypes请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: 实例ID
+        :type InstanceId: str
+        :param TargetNodeTypes: 接收请求的目标节点类型列表
+        :type TargetNodeTypes: list of str
+        """
+        self.InstanceId = None
+        self.TargetNodeTypes = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.TargetNodeTypes = params.get("TargetNodeTypes")
+
+
+class UpdateRequestTargetNodeTypesResponse(AbstractModel):
+    """UpdateRequestTargetNodeTypes返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class UpgradeInstanceRequest(AbstractModel):
     """UpgradeInstance请求参数结构体
 
